@@ -1,4 +1,4 @@
-# Copyright 2018 Splunk Inc. All rights reserved.
+# Copyright 2019 Splunk Inc. All rights reserved.
 
 """Checks contains both the group class and the check class. These classes
 serve as the basic scaffolding to connect the implied structure of validation
@@ -16,37 +16,37 @@ import operator
 import os
 import re
 import sys
+
 # Third-Party Libraries
 import bs4
 import markdown
 import six
+
 # Custom Libraries
 import splunk_appinspect
 import splunk_appinspect.infra
+from splunk_appinspect.configuration_parser import InvalidSectionError
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_CHECKS_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)),
-                                  'checks')
+DEFAULT_CHECKS_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), "checks")
 
 
 class ResourceUnavailableException(Exception):
     """An exception to throw when the Check class cannot find a resource needed
     for dependency injection.
     """
-    pass
 
 
 class ResourceCrashException(Exception):
     """An exception to throw when the Check class cannot setup a resource
     for dependency injection.
     """
-    pass
 
 
 def get_module_name_from_path(base, path):
     """Given a full path to a file, pull out the base filename."""
-    name, ext = os.path.splitext(os.path.relpath(path, base))
+    name, _ = os.path.splitext(os.path.relpath(path, base))
     return name.replace(os.sep, ".")
 
 
@@ -62,10 +62,14 @@ def import_group_modules(directory_paths):
     group_modules_to_return = []
 
     for check_dir in directory_paths:
-        file_pattern_regex = re.compile('check_.+.py$', re.IGNORECASE)
-        for directory_path, directory_names, file_names in os.walk(check_dir):
-            logger.debug("Beginning group generation on directory: {}".format(check_dir))
-            for file in [file_name for file_name in file_names if re.match(file_pattern_regex, file_name)]:
+        file_pattern_regex = re.compile("check_.+.py$", re.IGNORECASE)
+        for directory_path, _, file_names in os.walk(check_dir):
+            logger.debug("Beginning group generation on directory: %s", check_dir)
+            for file in [
+                file_name
+                for file_name in file_names
+                if re.match(file_pattern_regex, file_name)
+            ]:
                 filepath = os.path.join(directory_path, file)
                 group_module_name = get_module_name_from_path(check_dir, filepath)
                 group_module = imp.load_source(group_module_name, filepath)
@@ -84,14 +88,22 @@ def generate_checks(module):
 
     Arguments:
     """
-    checks = [Check(function_name, function)
-              for function_name, function
-              in inspect.getmembers(module, inspect.isfunction)
-              if function_name.startswith("check_")]
-    return checks
+    check_objects = [
+        Check(function_name, function)
+        for function_name, function in inspect.getmembers(module, inspect.isfunction)
+        if function_name.startswith("check_")
+    ]
+    return check_objects
 
 
-def generate_group(group_module, included_tags=None, excluded_tags=None, version=None, splunk_version='latest', custom_group=False):
+def generate_group(
+    group_module,
+    included_tags=None,
+    excluded_tags=None,
+    version=None,
+    splunk_version="latest",
+    custom_group=False,
+):
     """A helper function to create a group object based on a modules that is
     provided.
 
@@ -116,36 +128,42 @@ def generate_group(group_module, included_tags=None, excluded_tags=None, version
         version = splunk_appinspect.version.__version__
 
     # Group Generation
-    logger.debug("Beginning check generation on group name: {}".format(group_module.__name__))
+    logger.debug("Beginning check generation on group name: %s", group_module.__name__)
 
     # Check Generation
     check_list = generate_checks(group_module)
 
-    filtered_checks = [check
-                       for check in check_list
-                       if (check.matches_tags(included_tags, excluded_tags) and
-                           check.matches_version(version))]
+    filtered_checks = [
+        check
+        for check in check_list
+        if (
+            check.matches_tags(included_tags, excluded_tags)
+            and check.matches_version(version)
+        )
+    ]
 
     # Debuging output for check filtering
-    logger.debug("Included Tags: {}".format(",".join(included_tags)))
-    logger.debug("Excluded Tags: {}".format(",".join(excluded_tags)))
-    logger.debug("Version: {}".format(version))
-    logger.debug("Splunk Version: {}".format(splunk_version))
-    logger.debug("Is Custom Group: {}".format(custom_group))
+    logger.debug("Included Tags: %s", ",".join(included_tags))
+    logger.debug("Excluded Tags: %s", ",".join(excluded_tags))
+    logger.debug("Version: %s", version)
+    logger.debug("Splunk Version: %s", splunk_version)
+    logger.debug("Is Custom Group: %s", custom_group)
     logger.debug("--- All Checks ---")
     for check in check_list:
-        logger_output = ("check_name:{},matches_tags:{},matches_version:{}"
-                         ).format(check.name,
-                                  check.matches_tags(included_tags, excluded_tags),
-                                  check.matches_version(version))
+        logger_output = ("check_name:{},matches_tags:{},matches_version:{}").format(
+            check.name,
+            check.matches_tags(included_tags, excluded_tags),
+            check.matches_version(version),
+        )
         logger.debug(logger_output)
 
     logger.debug("--- Filtered Checks ---")
     for check in filtered_checks:
-        logger_output = ("check_name:{},matches_tags:{},matches_version:{}"
-                         ).format(check.name,
-                                  check.matches_tags(included_tags, excluded_tags),
-                                  check.matches_version(version))
+        logger_output = ("check_name:{},matches_tags:{},matches_version:{}").format(
+            check.name,
+            check.matches_tags(included_tags, excluded_tags),
+            check.matches_version(version),
+        )
         logger.debug(logger_output)
 
     new_group = Group(group_module, checks=filtered_checks, custom_group=custom_group)
@@ -153,7 +171,14 @@ def generate_group(group_module, included_tags=None, excluded_tags=None, version
     return new_group
 
 
-def groups(check_dirs=None, custom_checks_dir=None, included_tags=None, excluded_tags=None, version=None, splunk_version='latest'):
+def groups(
+    check_dirs=None,
+    custom_checks_dir=None,
+    included_tags=None,
+    excluded_tags=None,
+    version=None,
+    splunk_version="latest",
+):
     """Return a list of Group objects.
 
     Generates a list of Group objects by iterating through specified directories
@@ -177,12 +202,14 @@ def groups(check_dirs=None, custom_checks_dir=None, included_tags=None, excluded
     groups_to_return = []
     check_group_modules = import_group_modules(check_dirs)
     for group_module in check_group_modules:
-        check_group = generate_group(group_module,
-                                     included_tags=included_tags,
-                                     excluded_tags=excluded_tags,
-                                     version=version,
-                                     splunk_version=splunk_version,
-                                     custom_group=False)
+        check_group = generate_group(
+            group_module,
+            included_tags=included_tags,
+            excluded_tags=excluded_tags,
+            version=version,
+            splunk_version=splunk_version,
+            custom_group=False,
+        )
         # Don't return a group that does not have checks
         if list(check_group.checks()):
             groups_to_return.append(check_group)
@@ -193,19 +220,22 @@ def groups(check_dirs=None, custom_checks_dir=None, included_tags=None, excluded
     if custom_checks_dir:
         custom_group_modules = import_group_modules([custom_checks_dir])
         for group_module in custom_group_modules:
-            custom_check_group = generate_group(group_module,
-                                                included_tags=included_tags,
-                                                excluded_tags=excluded_tags,
-                                                version=version,
-                                                splunk_version=splunk_version,
-                                                custom_group=True)
+            custom_check_group = generate_group(
+                group_module,
+                included_tags=included_tags,
+                excluded_tags=excluded_tags,
+                version=version,
+                splunk_version=splunk_version,
+                custom_group=True,
+            )
 
             # Don't return a group that does not have checks
             if list(custom_check_group.checks()):
                 groups_to_return.append(custom_check_group)
 
-    groups_ordered_by_report_display_order = sorted(groups_to_return,
-                                                    key=operator.attrgetter('report_display_order'))
+    groups_ordered_by_report_display_order = sorted(
+        groups_to_return, key=operator.attrgetter("report_display_order")
+    )
     return groups_ordered_by_report_display_order
 
 
@@ -230,7 +260,9 @@ class Group(object):
     module docstring.
     """
 
-    def __init__(self, module, checks=None, report_display_order=None, custom_group=False):
+    def __init__(
+        self, module, checks=None, report_display_order=None, custom_group=False
+    ):
         """Constructor function."""
         self.name = module.__name__
         self.module = module
@@ -244,9 +276,7 @@ class Group(object):
 
         # Report Display Order
         if report_display_order is None:
-            report_order = getattr(module,
-                                   'report_display_order',
-                                   1000)
+            report_order = getattr(module, "report_display_order", 1000)
             if custom_group:
                 # Order custom checks to be last.
                 report_order += 10000
@@ -266,14 +296,14 @@ class Group(object):
         docstring = self.module.__doc__
         if docstring:
             return docstring
-        else:
-            return self.name
+
+        return self.name
 
     def doc_text(self):
         """Returns the plain text version of the doc string."""
         doc = self.doc_raw()
         soup = bs4.BeautifulSoup(markdown.markdown(doc), "lxml")
-        text = ''.join(soup.findAll(text=True))
+        text = "".join(soup.findAll(text=True))
         if self.custom_group:
             text = text + " (CUSTOM CHECK GROUP)"
         return text
@@ -281,21 +311,23 @@ class Group(object):
     def doc_name_human_readable(self):
         """Returns the contents of the Markdown h3 element from the top of the
         group's docstring."""
-        html = markdown.markdown(self.doc_raw(),
-                                 extensions=['markdown.extensions.fenced_code'])
-        bs_html = bs4.BeautifulSoup(html, 'html.parser')
-        if bs_html.h3 is not None and len(bs_html.h3.contents) > 0:
+        html = markdown.markdown(
+            self.doc_raw(), extensions=["markdown.extensions.fenced_code"]
+        )
+        bs_html = bs4.BeautifulSoup(html, "html.parser", store_line_numbers=False)
+        if bs_html.h3 is not None and bs_html.h3.contents:
             return text(bs_html.h3.contents[0]).strip()
         return u""
 
     def doc_html(self):
         """Returns the docstring (provided in markdown) as a html element."""
-        html = markdown.markdown(self.doc_raw(),
-                                 extensions=['markdown.extensions.fenced_code'])
-        bs_html = bs4.BeautifulSoup(html, 'html.parser')
+        html = markdown.markdown(
+            self.doc_raw(), extensions=["markdown.extensions.fenced_code"]
+        )
+        bs_html = bs4.BeautifulSoup(html, "html.parser", store_line_numbers=False)
         # Create a <a name="check_group_name"></a> to optionally be used for TOC
-        new_tag = bs_html.new_tag('a')
-        new_tag['name'] = self.name
+        new_tag = bs_html.new_tag("a")
+        new_tag["name"] = self.name
         bs_html.h3.contents.insert(0, new_tag)
         return text(bs_html)
 
@@ -308,7 +340,13 @@ class Group(object):
         # TODO: tests needed
         return len([check for check in self.checks(**kwargs)]) > 0
 
-    def count_total_static_checks(self, included_tags=None, excluded_tags=None, version=None, splunk_version='latest'):
+    def count_total_static_checks(
+        self,
+        included_tags=None,
+        excluded_tags=None,
+        version=None,
+        splunk_version="latest",
+    ):
         """A helper function to return the count of static checks.
 
         Returns:
@@ -329,16 +367,27 @@ class Group(object):
         if version is None:
             version = splunk_appinspect.version.__version__
 
-        total_static = len([check
-                            for check
-                            in self.checks(included_tags=included_tags,
-                                           excluded_tags=excluded_tags,
-                                           version=version,
-                                           splunk_version=splunk_version)
-                            if not check.is_dynamic_check()])
+        total_static = len(
+            [
+                check
+                for check in self.checks(
+                    included_tags=included_tags,
+                    excluded_tags=excluded_tags,
+                    version=version,
+                    splunk_version=splunk_version,
+                )
+                if not check.is_dynamic_check()
+            ]
+        )
         return total_static
 
-    def count_total_dynamic_checks(self, included_tags=None, excluded_tags=None, version=None, splunk_version='latest'):
+    def count_total_dynamic_checks(
+        self,
+        included_tags=None,
+        excluded_tags=None,
+        version=None,
+        splunk_version="latest",
+    ):
         """A helper function to return the count of standalone checks.
 
         Returns:
@@ -359,16 +408,27 @@ class Group(object):
         if version is None:
             version = splunk_appinspect.version.__version__
 
-        total_dynamic = len([check
-                             for check
-                             in self.checks(included_tags=included_tags,
-                                            excluded_tags=excluded_tags,
-                                            version=version,
-                                            splunk_version=splunk_version)
-                             if check.is_dynamic_check()])
+        total_dynamic = len(
+            [
+                check
+                for check in self.checks(
+                    included_tags=included_tags,
+                    excluded_tags=excluded_tags,
+                    version=version,
+                    splunk_version=splunk_version,
+                )
+                if check.is_dynamic_check()
+            ]
+        )
         return total_dynamic
 
-    def count_total_standalone_checks(self, included_tags=None, excluded_tags=None, version=None, splunk_version='latest'):
+    def count_total_standalone_checks(
+        self,
+        included_tags=None,
+        excluded_tags=None,
+        version=None,
+        splunk_version="latest",
+    ):
         """A helper function to return the count of standalone checks.
 
         Returns:
@@ -389,16 +449,27 @@ class Group(object):
         if version is None:
             version = splunk_appinspect.version.__version__
 
-        total_standalone = len([check
-                                for check
-                                in self.checks(included_tags=included_tags,
-                                               excluded_tags=excluded_tags,
-                                               version=version,
-                                               splunk_version=splunk_version)
-                                if check.is_standalone_check()])
+        total_standalone = len(
+            [
+                check
+                for check in self.checks(
+                    included_tags=included_tags,
+                    excluded_tags=excluded_tags,
+                    version=version,
+                    splunk_version=splunk_version,
+                )
+                if check.is_standalone_check()
+            ]
+        )
         return total_standalone
 
-    def count_total_cluster_checks(self, included_tags=None, excluded_tags=None, version=None, splunk_version='latest'):
+    def count_total_cluster_checks(
+        self,
+        included_tags=None,
+        excluded_tags=None,
+        version=None,
+        splunk_version="latest",
+    ):
         """A helper function to return the count of cluster checks.
 
         Returns:
@@ -419,13 +490,18 @@ class Group(object):
         if version is None:
             version = splunk_appinspect.version.__version__
 
-        total_cluster = len([check
-                             for check
-                             in self.checks(included_tags=included_tags,
-                                            excluded_tags=excluded_tags,
-                                            version=version,
-                                            splunk_version=splunk_version)
-                             if check.is_cluster_check()])
+        total_cluster = len(
+            [
+                check
+                for check in self.checks(
+                    included_tags=included_tags,
+                    excluded_tags=excluded_tags,
+                    version=version,
+                    splunk_version=splunk_version,
+                )
+                if check.is_cluster_check()
+            ]
+        )
         return total_cluster
 
     def add_check(self, check_to_add):
@@ -454,7 +530,13 @@ class Group(object):
         # TODO: tests needed
         self._checks.remove(check_to_remove)
 
-    def checks(self, included_tags=None, excluded_tags=None, version=None, splunk_version='latest'):
+    def checks(
+        self,
+        included_tags=None,
+        excluded_tags=None,
+        version=None,
+        splunk_version="latest",
+    ):
         """A function to return the checks that the group owns.
 
         Returns:
@@ -476,17 +558,22 @@ class Group(object):
 
         check_list = self._checks
 
-        ordered_checks = sorted(check_list,
-                                key=operator.attrgetter('report_display_order'))
+        ordered_checks = sorted(
+            check_list, key=operator.attrgetter("report_display_order")
+        )
 
         for check in ordered_checks:
-            should_check_be_returned = (check.matches_tags(included_tags, excluded_tags) and
-                                        check.matches_version(version))
-            logger_output = ("check_name:{},matches_tags:{},matches_version:{},should_check_be_returned:{}"
-                             ).format(check.name,
-                                      check.matches_tags(included_tags, excluded_tags),
-                                      check.matches_version(version),
-                                      should_check_be_returned)
+            should_check_be_returned = check.matches_tags(
+                included_tags, excluded_tags
+            ) and check.matches_version(version)
+            logger_output = (
+                "check_name:{},matches_tags:{},matches_version:{},should_check_be_returned:{}"
+            ).format(
+                check.name,
+                check.matches_tags(included_tags, excluded_tags),
+                check.matches_version(version),
+                should_check_be_returned,
+            )
             logger.debug(logger_output)
 
             if should_check_be_returned:
@@ -569,13 +656,13 @@ class Check(object):
         """
         # TODO: tests needed
         if six.PY2:
-            spec = inspect.getargspec(self.fun)
+            spec = inspect.getargspec(self.fun)  # pylint: disable=W1505
         else:
             spec = inspect.getfullargspec(self.fun)
         if "cluster" in spec.args:
             return True
-        else:
-            return False
+
+        return False
 
     def is_standalone_check(self):
         """A helper function identifiyng if the check does NOT require a splunk
@@ -587,13 +674,13 @@ class Check(object):
         """
         # TODO: tests needed
         if six.PY2:
-            spec = inspect.getargspec(self.fun)
+            spec = inspect.getargspec(self.fun)  # pylint: disable=W1505
         else:
             spec = inspect.getfullargspec(self.fun)
         if "standalone" in spec.args:
             return True
-        else:
-            return False
+
+        return False
 
     def has_tag(self, tags):
         """A helper function identifiyng if the check has tags.
@@ -617,12 +704,12 @@ class Check(object):
         if version_to_match is None:
             return True
 
-        if hasattr(self.fun, 'min_version'):
-            return (version_to_match >= self.fun.min_version and
-                    (self.fun.max_version is None or
-                     version_to_match <= self.fun.max_version))
-        else:
-            return True
+        if hasattr(self.fun, "min_version"):
+            return version_to_match >= self.fun.min_version and (
+                self.fun.max_version is None or version_to_match <= self.fun.max_version
+            )
+
+        return True
 
     def doc(self, include_version=False):
         """Returns the docstring provided with the underlying function, or the
@@ -641,8 +728,9 @@ class Check(object):
     def doc_html(self, include_version=False):
         """Returns the docstring (provided in markdown) as a html element."""
         # TODO: tests needed
-        html = markdown.markdown(self.doc_raw(),
-                                 extensions=['markdown.extensions.fenced_code'])
+        html = markdown.markdown(
+            self.doc_raw(), extensions=["markdown.extensions.fenced_code"]
+        )
 
         if include_version:
             html = "{} {}".format(html, self.version_doc())
@@ -653,11 +741,11 @@ class Check(object):
         """Returns the plain text version of the doc string."""
         # Normalize spacing (as found in code), keep line breaks
         # TODO: tests needed
-        p = re.compile(r'([ \t])+')
-        doc = p.sub(r'\1', self.doc_raw().strip())
+        p = re.compile(r"([ \t])+")
+        doc = p.sub(r"\1", self.doc_raw().strip())
 
         soup = bs4.BeautifulSoup(markdown.markdown(doc), "lxml")
-        text = ''.join(soup.findAll(text=True))
+        text = "".join(soup.findAll(text=True))
         return text
 
     def doc_raw(self):
@@ -666,8 +754,8 @@ class Check(object):
         docstring = self.fun.__doc__
         if docstring:
             return docstring
-        else:
-            return self.name
+
+        return self.name
 
     def version_doc(self):
         """Returns the version range of the check."""
@@ -682,45 +770,45 @@ class Check(object):
         Returns a report display order number. This indicates the order to
         display report elements in.
         """
-        if not getattr(self.fun, 'report_display_order', False):
+        if not getattr(self.fun, "report_display_order", False):
             return 1000
-        else:
-            return self.fun.report_display_order
+
+        return self.fun.report_display_order
 
     @property
     def deferred(self):
         """Returns true if the underlying function has 'deferred' advice. This
         is used for tests that should be run after all other tests.
         """
-        return getattr(self.fun, 'deferred', False)
+        return getattr(self.fun, "deferred", False)
 
     @property
     def min_version_doc(self):
         """Returns the min version specified against the check."""
         # TODO: tests needed
-        if not getattr(self.fun, 'min_version', False):
+        if not getattr(self.fun, "min_version", False):
             return "1.0"
-        else:
-            return self.fun.min_version
+
+        return self.fun.min_version
 
     @property
     def max_version_doc(self):
         """Returns the max version specified against the check."""
         # TODO: tests needed
-        if not getattr(self.fun, 'max_version', False):
+        if not getattr(self.fun, "max_version", False):
             return "*"
-        else:
-            return self.fun.max_version
+
+        return self.fun.max_version
 
     @property
     def tags(self):
         """Returns the tags of the checks if they exist  or returns an empty
         tuple.
         """
-        if hasattr(self.fun, 'tags'):
+        if hasattr(self.fun, "tags"):
             return self.fun.tags
-        else:
-            return tuple()
+
+        return tuple()
 
     def matches_tags(self, included_tags, excluded_tags):
         """Returns a boolean.
@@ -745,22 +833,27 @@ class Check(object):
         :param excluded_tags (A list of Strings) - Exclude checks with these tags
         """
         check_tags_set = set(self.tags)
-        included_tags_set, excluded_tags_set = splunk_appinspect.infra.refine_tag_set(included_tags, excluded_tags)
-        if(not included_tags_set and
-                not excluded_tags_set):
+        included_tags_set, excluded_tags_set = splunk_appinspect.infra.refine_tag_set(
+            included_tags, excluded_tags
+        )
+        if not included_tags_set and not excluded_tags_set:
             return True
-        elif(included_tags_set and
-             not excluded_tags_set):
-            return (not check_tags_set.isdisjoint(included_tags_set))
-        elif(not included_tags_set and
-             excluded_tags_set):
-            return check_tags_set.isdisjoint(excluded_tags_set)
-        elif(included_tags_set and
-             excluded_tags_set):
-            return (not check_tags_set.isdisjoint(included_tags_set) 
-                    and check_tags_set.isdisjoint(excluded_tags_set))
 
-    def run(self, app, resource_manager_context={}):
+        if included_tags_set and not excluded_tags_set:
+            return not check_tags_set.isdisjoint(included_tags_set)
+
+        if not included_tags_set and excluded_tags_set:
+            return check_tags_set.isdisjoint(excluded_tags_set)
+
+        if included_tags_set and excluded_tags_set:
+
+            return not check_tags_set.isdisjoint(
+                included_tags_set
+            ) and check_tags_set.isdisjoint(excluded_tags_set)
+
+        return True
+
+    def run(self, app, resource_manager_context=None):
         """This is in a way the central method of this library.  A check can be
         run, and it returns a 'reporter' object.  Whatever the result- success,
         failure, exception, etc, it will be encoded in that reporter
@@ -782,10 +875,12 @@ class Check(object):
           extended so that if the value is callable, it will be called and the
           result will be passed in as that parameter.
         """
+        if not resource_manager_context:
+            resource_manager_context = {}
         reporter = splunk_appinspect.reporter.Reporter()
         reporter.start()
         try:
-            logging.debug("Executing " + self.name)
+            logging.debug("Executing %s", self.name)
             # This is a bit of magic, the idea for which was taken from pytest.
             # Basically checks will need some variety of app, reporter, and/or
             # access to a splunk instance (or instances).  Instead of having a
@@ -800,12 +895,14 @@ class Check(object):
             # parameter becomes an available argument to the checks.
             available_args = dict()
 
-            available_args['app'] = app
-            available_args['reporter'] = reporter
+            available_args["app"] = app
+            available_args["reporter"] = reporter
 
             args = []
             if six.PY2:
-                function_arguments = inspect.getargspec(self.fun).args
+                function_arguments = inspect.getargspec(
+                    self.fun
+                ).args  # pylint: disable=W1505
             else:
                 function_arguments = inspect.getfullargspec(self.fun).args
             for arg in function_arguments:
@@ -817,48 +914,64 @@ class Check(object):
                         args.append(val)
                 elif arg in resource_manager_context:
                     # TODO: tests needed
-                    logging.debug("Getting resource: '{}' for {}".format(arg,
-                                                                         self.fun.__name__))
+                    logging.debug(
+                        "Getting resource: '%s' for %s", arg, self.fun.__name__
+                    )
 
                     rm_ctx = resource_manager_context[arg]
-                    if hasattr(rm_ctx, 'state') and rm_ctx.state != 0:
-                        error_string = ("{} has been skipped because the specified"
-                                        " resource {} provided could not be setup correctly."
-                                        ).format(self.fun.__name__, rm_ctx.__class__.__name__)
+                    if hasattr(rm_ctx, "state") and rm_ctx.state != 0:
+                        error_string = (
+                            "{} has been skipped because the specified"
+                            " resource {} provided could not be setup correctly."
+                        ).format(self.fun.__name__, rm_ctx.__class__.__name__)
 
-                        logger.debug("Resource {} has an invalid state {}".format(rm_ctx.__class__.__name__, rm_ctx.state))
+                        logger.debug(
+                            "Resource %s has an invalid state %s",
+                            rm_ctx.__class__.__name__,
+                            rm_ctx.state,
+                        )
                         raise ResourceUnavailableException(error_string)
 
                     args.append(rm_ctx)
-                elif hasattr(resource_manager_context, 'context') and arg in resource_manager_context.context:
-                    logging.debug("Getting arguement: '{}' for {}".format(arg,
-                                                                         self.fun.__name__))
+                elif (
+                    hasattr(resource_manager_context, "context")
+                    and arg in resource_manager_context.context
+                ):
+                    logging.debug(
+                        "Getting argument: '%s' for %s", arg, self.fun.__name__
+                    )
+
                     args.append(resource_manager_context.context[arg])
                 else:
                     # TODO: tests needed
-                    error_string = ("{} has been skipped because the specified"
-                                    " instances provided did not match the"
-                                    " required instance types."
-                                    " Instances provided: {}."
-                                    "").format(self.fun.__name__,
-                                               resource_manager_context.keys())
+                    error_string = (
+                        "{} has been skipped because the specified"
+                        " instances provided did not match the"
+                        " required instance types."
+                        " Instances provided: {}."
+                        ""
+                    ).format(self.fun.__name__, resource_manager_context.keys())
                     raise ResourceUnavailableException(error_string)
             self.fun.__call__(*args)
         except NotImplementedError:
             e = sys.exc_info()
-            reporter.exception(e, 'failure')
+            reporter.exception(e, "failure")
         except ResourceUnavailableException:
             e = sys.exc_info()
-            reporter.exception(e, 'skipped')
+            reporter.exception(e, "skipped")
         except ResourceCrashException as e:
             reporter.fail(str(e))
+        except InvalidSectionError as e:
+            reporter.fail(
+                "{} is malformed. Details: {}".format(e.file_name, str(e)),
+                e.file_name,
+                e.line_no,
+            )
         except:
             e = sys.exc_info()
             logging.exception(e)
             reporter.exception(e)
-        logging.debug("check %s %s",
-                      self.name,
-                      reporter.state())
+        logging.debug("check %s %s", self.name, reporter.state())
 
         reporter.complete()
         return reporter
