@@ -123,7 +123,7 @@ def check_for_real_time_saved_searches(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "savedsearches")
+@splunk_appinspect.tags("cloud", "savedsearches", "private_app")
 @splunk_appinspect.cert_version(min="1.5.4")
 def check_for_real_time_saved_searches_for_cloud(app, reporter):
     """Check that no real-time pre-index saved searches are being used in
@@ -161,7 +161,7 @@ def check_for_real_time_saved_searches_for_cloud(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "savedsearches")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "savedsearches", "private_app")
 @splunk_appinspect.cert_version(min="1.1.20")
 def check_for_gratuitous_cron_scheduling(app, reporter):
     """Check that `default/savedsearches.conf` searches are cron scheduled
@@ -265,7 +265,7 @@ def check_for_empty_saved_search_description(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "savedsearches")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "savedsearches", "private_app")
 @splunk_appinspect.cert_version(min="1.5.3")
 def check_for_sched_saved_searches_earliest_time(app, reporter):
     """Check that if a scheduled saved search in savedsearch.conf contains dispatch.earliest_time option,
@@ -313,7 +313,7 @@ def _is_summary_search_with_earliest_time(section):
     )
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "savedsearches")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "savedsearches", "private_app")
 @splunk_appinspect.cert_version(min="1.5.3")
 def check_for_sched_saved_searches_latest_time(app, reporter):
     """Check that if a savedsearch.conf stanza contains scheduling options
