@@ -27,7 +27,7 @@ logger = logging.getLogger(__name__)
 report_display_order = 5
 
 
-@splunk_appinspect.tags("splunk_appinspect", "appapproval", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "appapproval", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.0.0")
 def check_for_bin_files(app, reporter):
     """Check that files outside of the `bin/` and `appserver/controllers` directory do not have execute
