@@ -3,11 +3,14 @@ from splunk_appinspect.python_analyzer.trustedlibs import utilities
 
 
 class TrustedLibsManager(object):
-    def __init__(self,
-                 trusted_checks_and_libs_file=trusted_data_collector.TRUSTED_CHECK_AND_LIBS_FILE,
-                 untrusted_check_and_libs_file=trusted_data_collector.UNTRUSTED_CHECK_AND_LIBS_FILE):
-        self.libs_data = trusted_data_collector.TrustedDataCollector(trusted_checks_and_libs_file,
-                                                                     untrusted_check_and_libs_file)
+    def __init__(
+        self,
+        trusted_checks_and_libs_file=trusted_data_collector.TRUSTED_CHECK_AND_LIBS_FILE,
+        untrusted_check_and_libs_file=trusted_data_collector.UNTRUSTED_CHECK_AND_LIBS_FILE,
+    ):
+        self.libs_data = trusted_data_collector.TrustedDataCollector(
+            trusted_checks_and_libs_file, untrusted_check_and_libs_file
+        )
 
     def check_if_lib_is_trusted(self, checkname, lib=None, content_hash=None):
         """
